@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,7 +30,7 @@ selection method.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/msvs.py issue-2856:2676:d23b7a2f45e8 2012/08/05 15:38:28 garyo"
+__revision__ = "src/engine/SCons/Tool/msvs.py  2014/03/02 14:18:15 garyo"
 
 import SCons.compat
 
@@ -1206,7 +1206,7 @@ class _GenerateV7DSW(_DSWGenerator):
         self.version_num, self.suite = msvs_parse_version(self.version)
         self.versionstr = '7.00'
         if self.version_num >= 11.0:
-            self.versionstr = '12.0'
+            self.versionstr = '12.00'
         elif self.version_num >= 10.0:
             self.versionstr = '11.00'
         elif self.version_num >= 9.0:
@@ -1311,7 +1311,7 @@ class _GenerateV7DSW(_DSWGenerator):
     def PrintSolution(self):
         """Writes a solution file"""
         self.file.write('Microsoft Visual Studio Solution File, Format Version %s\n' % self.versionstr)
-        if self.versionstr >= 11.0:
+        if self.version_num >= 11.0:
             self.file.write('# Visual Studio 11\n')
         elif self.version_num >= 10.0:
             self.file.write('# Visual Studio 2010\n')
@@ -1654,6 +1654,10 @@ def projectEmitter(target, source, env):
         t, s = solutionEmitter(target, target, env)
         targetlist = targetlist + t
 
+    # Beginning with Visual Studio 2010 for each project file (.vcxproj) we have additional file (.vcxproj.filters)
+    if float(env['MSVS_VERSION']) >= 10.0:
+        targetlist.append(targetlist[0] + '.filters')
+
     return (targetlist, sourcelist)
 
 def solutionEmitter(target, source, env):
