@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -32,13 +32,13 @@ NOTE: Installed SCons is not importable like usual Python packages. It is
       below is dedicated to make it happen on various platforms.
 """
 
-__revision__ = "src/setup.py  2013/03/03 09:48:35 garyo"
+__revision__ = "src/setup.py  2014/03/02 14:18:15 garyo"
 
 import os
 import stat
 import sys
 
-Version = "2.3.0"
+Version = "2.3.1"
 
 man_pages = [
     'scons.1',
@@ -408,11 +408,81 @@ arguments = {
                           "SCons.Scanner",
                           "SCons.Script",
                           "SCons.Tool",
+                          "SCons.Tool.docbook",
                           "SCons.Tool.MSCommon",
                           "SCons.Tool.packaging",
                           "SCons.Variables",
                          ],
-    'package_dir'      : {'' : 'engine'},
+    'package_dir'      : {'' : 'engine',
+                          'SCons.Tool.docbook' : 'engine/SCons/Tool/docbook'},
+    'package_data'     : {'SCons.Tool.docbook' : ['docbook-xsl-1.76.1/*',
+                                                  'docbook-xsl-1.76.1/common/*',
+                                                  'docbook-xsl-1.76.1/docsrc/*',
+                                                  'docbook-xsl-1.76.1/eclipse/*',
+                                                  'docbook-xsl-1.76.1/epub/*',
+                                                  'docbook-xsl-1.76.1/epub/bin/*',
+                                                  'docbook-xsl-1.76.1/epub/bin/lib/*',
+                                                  'docbook-xsl-1.76.1/epub/bin/xslt/*',
+                                                  'docbook-xsl-1.76.1/extensions/*',
+                                                  'docbook-xsl-1.76.1/fo/*',
+                                                  'docbook-xsl-1.76.1/highlighting/*',
+                                                  'docbook-xsl-1.76.1/html/*',
+                                                  'docbook-xsl-1.76.1/htmlhelp/*',
+                                                  'docbook-xsl-1.76.1/images/*',
+                                                  'docbook-xsl-1.76.1/images/callouts/*',
+                                                  'docbook-xsl-1.76.1/images/colorsvg/*',
+                                                  'docbook-xsl-1.76.1/javahelp/*',
+                                                  'docbook-xsl-1.76.1/lib/*',
+                                                  'docbook-xsl-1.76.1/manpages/*',
+                                                  'docbook-xsl-1.76.1/params/*',
+                                                  'docbook-xsl-1.76.1/profiling/*',
+                                                  'docbook-xsl-1.76.1/roundtrip/*',
+                                                  'docbook-xsl-1.76.1/slides/browser/*',
+                                                  'docbook-xsl-1.76.1/slides/fo/*',
+                                                  'docbook-xsl-1.76.1/slides/graphics/*',
+                                                  'docbook-xsl-1.76.1/slides/graphics/active/*',
+                                                  'docbook-xsl-1.76.1/slides/graphics/inactive/*',
+                                                  'docbook-xsl-1.76.1/slides/graphics/toc/*',
+                                                  'docbook-xsl-1.76.1/slides/html/*',
+                                                  'docbook-xsl-1.76.1/slides/htmlhelp/*',
+                                                  'docbook-xsl-1.76.1/slides/keynote/*',
+                                                  'docbook-xsl-1.76.1/slides/keynote/xsltsl/*',
+                                                  'docbook-xsl-1.76.1/slides/svg/*',
+                                                  'docbook-xsl-1.76.1/slides/xhtml/*',
+                                                  'docbook-xsl-1.76.1/template/*',
+                                                  'docbook-xsl-1.76.1/tests/*',
+                                                  'docbook-xsl-1.76.1/tools/bin/*',
+                                                  'docbook-xsl-1.76.1/tools/make/*',
+                                                  'docbook-xsl-1.76.1/webhelp/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/css/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/images/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/jquery/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/jquery/theme-redmond/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/jquery/theme-redmond/images/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/jquery/treeview/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/common/jquery/treeview/images/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/content/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/content/search/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docs/content/search/stemmers/*',
+                                                  'docbook-xsl-1.76.1/webhelp/docsrc/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/css/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/images/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/jquery/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/jquery/theme-redmond/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/jquery/theme-redmond/images/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/jquery/treeview/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/common/jquery/treeview/images/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/content/search/*',
+                                                  'docbook-xsl-1.76.1/webhelp/template/content/search/stemmers/*',
+                                                  'docbook-xsl-1.76.1/webhelp/xsl/*',
+                                                  'docbook-xsl-1.76.1/website/*',
+                                                  'docbook-xsl-1.76.1/xhtml/*',
+                                                  'docbook-xsl-1.76.1/xhtml-1_1/*',
+                                                  'utils/*']},
     'data_files'       : [('man/man1', man_pages)],
     'scripts'          : scripts,
     'cmdclass'         : {'install'         : install,
